#
# spec file for package pdnsd
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} == 1315 && !0%{?is_opensuse}
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif
%endif

Name:           pdnsd

%define _cache_dir  %{_localstatedir}/cache/%{name}
%define _cache_file %{_cache_dir}/%{name}.cache

Version:        1.2.9a
Release:        11.1
Summary:        A caching DNS proxy for small networks or dialin accounts
License:        GPL-3.0-or-later
Group:          Productivity/Networking/DNS/Servers
URL:            http://members.home.nl/p.a.rombouts/pdnsd.html

#Source0:        http://members.home.nl/p.a.rombouts/%{name}/releases/%{name}-%{version}-par.tar.gz
Source0:        %{name}-%{version}-par.tar.gz
Source1:        %{name}.sysconfig
%if 0%{?suse_version} == 1315 && !0%{?is_opensuse}
Source2:        %{name}.service.sle12
%else
Source2:        %{name}.service
%endif
# PATCH-FIX-OPENSUSE -- fix UDP response packet for large responses being incorrectly truncated -- seife@novell.slipkontur.de
Patch1:         %{name}-fix-udppacketsize.diff
# borrowed from debian's 1.2.9a-par-3 release
Patch2:         %{name}-06_reproducible_build.patch
# PATCH-FIX-OPENSUSE -- compile fix with newer glibc(?)/kernel-headers(?) where ordering matters -- seife+obs@b1-systems.com
Patch3:         %{name}-net_if_h-vs-linux_if_h.patch
# PATCH-FIX-OPENSUSE -- cleanup default config
Patch100:       %{name}_conf.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  systemd-rpm-macros
Recommends:     %{name}-doc
%{?systemd_ordering}

%description
pdnsd is a proxy DNS daemon with permanent (disk-)cache and the ability
to serve local records. It is designed to detect network outages or hangups
and to prevent DNS-dependent applications like Netscape Navigator from hanging.

The original author of pdnsd is Thomas Moestl, but pdnsd is no longer maintained
by him. This is an extensively revised version by Paul A. Rombouts.
For a description of the changes see http://www.phys.uu.nl/~rombouts/pdnsd.html
and the file README.par in %{_docdir}/%{name}-doc.

%package doc
Summary:        Docs for pdnsd 
Group:          Productivity/Networking/DNS/Servers
BuildArch:      noarch
Requires:       %{name}

%description doc
This package provides various text files for pdnsd

%prep
%setup -q
%autopatch -p0

%build
%configure \
  --enable-ipv6 \
  --enable-specbuild \
  --with-cachedir="%{_cache_dir}" \
  --with-default-id=pdns \
  --with-query-method=udptcp \
  --with-par-queries=3

make %{?_smp_mflags}

%install
%make_install
install -D -m 0644 %{S:1} %{buildroot}%{_fillupdir}/sysconfig.%{name}
cp -a %{buildroot}%{_sysconfdir}/%{name}.conf.sample %{buildroot}%{_sysconfdir}/%{name}.conf
install -D -m 0644 %{S:2} %{buildroot}%{_unitdir}/%{name}.service
sed -i -e "s|@cache_file@|%{_cache_file}|" \
 -e "s/@user@/pdns/" -e "s/@group@/pdns/" %{buildroot}%{_unitdir}/%{name}.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

%pre
# add group
%{_sbindir}/groupadd -r pdns 2>/dev/null || :
# add user
%{_sbindir}/useradd -c "DNS proxy account" -d %{_cache_dir} -G pdns -g pdns \
  -r -s /sbin/nologin pdns 2>/dev/null || :
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%post
%service_add_post %{name}.service
%{fillup_only -n pdnsd}

%postun
%service_del_postun %{name}.service

%files
%defattr(-,root,root)
%config(noreplace) %attr(0640,root,pdns) %{_sysconfdir}/%{name}.conf
%{_sysconfdir}/%{name}.conf.sample
%{_sbindir}/*%{name}*
%{_mandir}/man*/%{name}*
%dir %attr(0750,pdns,pdns) %{_cache_dir}
%ghost %attr(-,pdns,pdns) %{_cache_file}
%{_unitdir}/%{name}.service
%{_fillupdir}/sysconfig.%{name}

%files doc
%defattr(-,root,root)
%doc AUTHORS ChangeLog COPYING* NEWS README* THANKS TODO

%changelog
* Wed Oct 11 2023 Dominique Leuenberger <dimstar@opensuse.org>
- No longer reference the full URL to the tarball: the website no
  longer exists (pdnsd 1.2.9a was released in March 2012).
* Thu Sep 15 2022 chris@computersalat.de
- rework patches to be p0
- add pdnsd_conf.patch
  * mainly just beautification for better readability
- add pdnsd.sysconfig file
  * ability to pass ARGS
- service files
  * update pdnsd.service
  * add pdnsd.service.sle12
- add user/group pdns
* Mon Oct 18 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * pdnsd.service
* Thu Jul 29 2021 Stefan Seyfried <seife+obs@b1-systems.com>
- add pdnsd-net_if_h-vs-linux_if_h.patch to fix Factory build
- add a locally tested collection of patches:
  * pdnsd-06_reproducible_build.patch for reproducible build
  * pdnsd-fix-udppacketsize.diff fixing an invalid UDP response
    packet truncation encountered in the wild
* Tue May 28 2019 Jan Engelhardt <jengelh@inai.de>
- Do not ignore errors from groupadd.
- Convert sysvinit script to systemd service unit. [boo#1116030]
* Wed Mar 15 2017 dimstar@opensuse.org
- Add %%insserv_prereq PreReq: since we still install legacy initd
  services it is our own duty to ensure the legacy tools to handle
  them are installed.
* Wed Jul 23 2014 meissner@suse.com
- make init script executable, fix build
* Sun May 19 2013 dap.darkness@gmail.com
- Changes file was fixed up in according to sr's #175639 & #175789.
- Switched from user nobody to pdns to correspond Factory rules.
* Tue May 14 2013 dap.darkness@gmail.com
- Branched from home:Reki.
- Updated from 1.2.9 to 1.2.9a.
- Spec-file was completely fixed up.
